@@ -22,13 +22,4 @@ class DimensionTestSuite(BaseTestSuite):
         names = loader.getTestCaseNames(CommonTestCase)
 
         for name in names:
-            self.TestSuite.addTest(CommonTestCase(self.TableDataFrame, self.FieldInfo, self.CustomEvents, name))
-
-    def run_tests(self) -> None:
-
-        self.TestRunner.run(self.TestSuite)
-
-        for event in self.CustomEvents:
-            print(str(event))
-
-        self.dump_events()
\ No newline at end of file
+            self.TestSuite.addTest(CommonTestCase(self.TableDataFrame, self.FieldInfo, self.CustomEvents, name))
\ No newline at end of file
