@@ -20,19 +20,18 @@ class TestEvent(object):
     
     def __str__(self) -> str:
 
+        # we'd prefer to use dumps(self.__dict__) but pyspark types are not json serializable
+
         d = {}
 
         d["test_name"] = self.TestName
+        d["start"] = str(self.Start)
+        d["end"] = str(self.End)
+        d["duration"] = str(self.EventDurationSeconds)
         d["notes"] = {}
 
         for key in self.Notes.keys():
             d["notes"][key] = [str(e) for e in self.Notes[key]]
-            print([str(e) for e in self.Notes[key]])
-
-
-        d["start"] = str(self.Start)
-        d["end"] = str(self.End)
-        d["duration"] = str(self.EventDurationSeconds)
 
         s = dumps(d)
 
